<?php

namespace Drupal\wysiwyg_linebreaks\Plugin\CKEditor5Plugin;

use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableInterface;
use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableTrait;
use Drupal\ckeditor5\Plugin\CKEditor5PluginDefault;
use Drupal\Core\Form\FormStateInterface;
use Drupal\editor\EditorInterface;

/**
 * CKEditor 5 Linebreaks plugin configuration.
 *
 * @internal
 *    Plugin classes are internal.
 */
class LineBreaks extends CKEditor5PluginDefault implements CKEditor5PluginConfigurableInterface {

  use CKEditor5PluginConfigurableTrait;

  /**
   * {@inheritdoc}
   */
  public function getDynamicPluginConfig(array $static_plugin_config, EditorInterface $editor): array {
    return [
      'linebreaks' => [
        'method' => $this->configuration['method'],
      ],
    ];
  }

  /**
   * @inheritDoc
   */
  public function defaultConfiguration() {
    return [
      'method' => 'force',
    ];
  }

  /**
   * @inheritDoc
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $default = $this->defaultConfiguration();
    $form['method'] = [
      '#type' => 'radios',
      '#title' => $this->t('Conversion Method'),
      '#default_value' => $this->configuration['method'] ?? $default['method'],
      '#options' => [
        'force' => $this->t('Force linebreaks'),
        'convert' => $this->t('Convert linebreaks'),
      ],
      '#description' => $this->t('Set to Force linebreaks if you never want to see <code>&lt;p&gt;</code> and
        <code>&lt;br /&gt;</code> tags in your content when editing without a Wysiwyg editor. Set to Convert linebreaks
         if you have content without <code>&lt;p&gt;</code> and <code>&lt;br /&gt;</code> tags that needs to be
          converted so it is still formatted correctly in the Wysiwyg editor.'),
    ];

    return $form;
  }

  /**
   * @inheritDoc
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * @inheritDoc
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['method'] = $form_state->getValue('method');
  }

}
